#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rere
version:              0.2
visibility:           public
id:                   rere-0.2-31kxQ4dOfPuJxPePnLgTCS
key:                  rere-0.2-31kxQ4dOfPuJxPePnLgTCS
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  6d8bf9fd703badd7698de8c1a9df0d1c
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-8.10.5/site-local/rere-0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/rere-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/rere-0.2
hs-libraries:         HSrere-0.2-31kxQ4dOfPuJxPePnLgTCS
depends:
    QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD base-4.14.2.0
    containers-0.6.4.1 fin-0.2-Jh4GoCBalwdLRITRmOhXo2 parsec-3.1.14.0
    transformers-0.5.6.2 vec-0.4-LJY3nuJ0tC5L6PUX7GwxMx

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

